@@ -93,7 +93,7 @@ class Builder():
 
   def changesetFromDay(self, date):
     try:
-      hgstring = subprocess.Popen(hgPrefix+['log','-d',date,'-l','1'],stdout=subprocess.PIPE)
+      hgstring = subprocess.Popen(hgPrefix+['log','-r',':','-d',date,'-l','1'],stdout=subprocess.PIPE)
       parsestring = hgstring.communicate()
       try:
         changesetString = parsestring[0].split("\n")[0].split(":")[2]
